@@ -1,7 +1,7 @@
-#!/usr/bin/env python3
-"""
-Upload release notes into GitHub releases.
-"""
+# Licensed under the Apache License: http://www.apache.org/licenses/LICENSE-2.0
+# For details: https://github.com/nedbat/coveragepy/blob/master/NOTICE.txt
+
+"""Upload release notes into GitHub releases."""
 
 import json
 import shlex
