@@ -5,17 +5,16 @@
 
 import os
 import os.path
+from unittest import mock
 
 import pytest
 
-from coverage import env
-from coverage import files
-from coverage.exceptions import CoverageException
+from coverage import env, files
+from coverage.exceptions import ConfigError
 from coverage.files import (
-    TreeMatcher, FnmatchMatcher, ModuleMatcher, PathAliases,
-    find_python_files, abs_file, actual_path, flat_rootname, fnmatches_to_regex,
+    FnmatchMatcher, ModuleMatcher, PathAliases, TreeMatcher, abs_file,
+    actual_path, find_python_files, flat_rootname, fnmatches_to_regex,
 )
-
 from tests.coveragetest import CoverageTest
 
 
@@ -67,6 +66,19 @@ class FilesTest(CoverageTest):
         assert 'sub/proj1/file1.py' in files.CANONICAL_FILENAME_CACHE
         assert files.canonical_filename('sub/proj1/file1.py') == self.abs_path('file1.py')
 
+    @pytest.mark.parametrize(
+        ["curdir", "sep"], [
+            ("/", "/"),
+            ("X:\\", "\\"),
+        ]
+    )
+    def test_relative_dir_for_root(self, curdir, sep):
+        with mock.patch.object(files.os, 'curdir', new=curdir):
+            with mock.patch.object(files.os, 'sep', new=sep):
+                with mock.patch('coverage.files.os.path.normcase', return_value=curdir):
+                    files.set_relative_directory()
+                    assert files.relative_directory() == curdir
+
 
 @pytest.mark.parametrize("original, flat", [
     ("abc.py", "abc_py"),
@@ -170,7 +182,7 @@ class MatcherTest(CoverageTest):
             files.canonical_filename("sub3/file4.py"),
             files.canonical_filename("sub4/file5.py"),
             files.canonical_filename("SUB5/file6.py"),
-            ]
+        ]
         tm = TreeMatcher(trees)
         assert tm.info() == sorted(trees)
         for filepath, matches in matches_to_try:
@@ -291,7 +303,7 @@ class PathAliasesTest(CoverageTest):
     def test_cant_have_wildcard_at_end(self, badpat):
         aliases = PathAliases()
         msg = "Pattern must not end with wildcards."
-        with pytest.raises(CoverageException, match=msg):
+        with pytest.raises(ConfigError, match=msg):
             aliases.add(badpat, "fooey")
 
     def test_no_accidental_munging(self):
@@ -418,7 +430,7 @@ class FindPythonFilesTest(CoverageTest):
             "sub/a.py", "sub/b.py",
             "sub/ssub/__init__.py", "sub/ssub/s.py",
             "sub/windows.pyw",
-            ])
+        ])
 
 
 @pytest.mark.skipif(not env.WINDOWS, reason="Only need to run Windows tests on Windows.")
